=============================
django-bank
=============================

.. image:: https://badge.fury.io/py/django-bank.png
    :target: https://badge.fury.io/py/django-bank

.. image:: https://travis-ci.org/niktto/django-bank.png?branch=master
    :target: https://travis-ci.org/niktto/django-bank

Small Django app helping you to handle your users accounts

Documentation
-------------

The full documentation is at https://django-bank.readthedocs.org.

Quickstart
----------

Install django-bank::

    pip install django-bank

Then use it in a project::

    import django-bank

Features
--------

* TODO
